@@ -1,12 +1,17 @@
 # -*- coding: utf-8 -*-
 #
 # Picard, the next-generation MusicBrainz tagger
+#
 # Copyright (C) 2007 Oliver Charles
-# Copyright (C) 2007-2011 Philipp Wolfer
-# Copyright (C) 2007, 2010, 2011 Lukáš Lalinský
+# Copyright (C) 2007, 2010-2011 Lukáš Lalinský
+# Copyright (C) 2007-2011, 2014, 2018-2020 Philipp Wolfer
 # Copyright (C) 2011 Michael Wiencek
-# Copyright (C) 2011-2012 Wieland Hoffmann
-# Copyright (C) 2013-2014 Laurent Monin
+# Copyright (C) 2011-2012, 2015 Wieland Hoffmann
+# Copyright (C) 2013-2015, 2018-2019 Laurent Monin
+# Copyright (C) 2016 Ville Skyttä
+# Copyright (C) 2016-2018 Sambhav Kothari
+# Copyright (C) 2017 Antonio Larrosa
+# Copyright (C) 2018 Vishal Choudhary
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -21,6 +26,8 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+
+
 from hashlib import md5
 import os
 import shutil
@@ -30,6 +37,7 @@ from PyQt5.QtCore import (
     QMutex,
     QObject,
     QUrl,
+    QUrlQuery,
 )
 
 from picard import (
@@ -42,6 +50,7 @@ from picard.util import (
     decode_filename,
     encode_filename,
     imageinfo,
+    is_absolute_path,
 )
 from picard.util.scripttofilename import script_to_filename
 
@@ -158,7 +167,10 @@ class CoverArtImage:
         self.port = self.url.port(443 if self.url.scheme() == 'https' else 80)
         self.path = self.url.path(QUrl.FullyEncoded)
         if self.url.hasQuery():
-            self.path += '?' + self.url.query(QUrl.FullyEncoded)
+            query = QUrlQuery(self.url.query())
+            self.queryargs = dict(query.queryItems())
+        else:
+            self.queryargs = None
 
     @property
     def source(self):
@@ -253,7 +265,7 @@ class CoverArtImage:
 
         try:
             self.datahash = DataHash(data, suffix=self.extension)
-        except (OSError, IOError) as e:
+        except OSError as e:
             raise CoverArtImageIOError(e)
 
     @property
@@ -265,7 +277,7 @@ class CoverArtImage:
         """
         if self.is_front_image() or not self.types or 'front' in self.types:
             return 'front'
-        # TODO: do something better than randomly using the first in the list
+        # TODO: do something better than randomly using the first in the list
         return self.types[0]
 
     def _make_image_filename(self, filename, dirname, _metadata):
@@ -280,7 +292,7 @@ class CoverArtImage:
         filename = script_to_filename(filename, metadata)
         if not filename:
             filename = "cover"
-        if not os.path.isabs(filename):
+        if not is_absolute_path(filename):
             filename = os.path.join(dirname, filename)
         return encode_filename(filename)
 
@@ -323,7 +335,7 @@ class CoverArtImage:
                 if not os.path.isdir(new_dirname):
                     os.makedirs(new_dirname)
                 shutil.copyfile(self.tempfile_filename, new_filename)
-            except (OSError, IOError) as e:
+            except OSError as e:
                 raise CoverArtImageIOError(e)
 
     def _next_filename(self, filename, counters):
@@ -348,7 +360,7 @@ class CoverArtImage:
         """
         try:
             return self.datahash.data
-        except (OSError, IOError) as e:
+        except OSError as e:
             raise CoverArtImageIOError(e)
 
     @property
